Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(93)

Unified Diff: tools/testing/dart/multitest.dart

Issue 10699006: Add test for native extensions that copies the extension to a test directory and runs it. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fix comment and long line in multitest.dart Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: tools/testing/dart/multitest.dart
diff --git a/tools/testing/dart/multitest.dart b/tools/testing/dart/multitest.dart
index 5170ac1f46a5fe553e78033548179ce4f1c67de5..4e1b71665163fd867693d6f6ef7bea150664b3f2 100644
--- a/tools/testing/dart/multitest.dart
+++ b/tools/testing/dart/multitest.dart
@@ -160,9 +160,9 @@ Set<String> _findAllRelativeImports(String topLibrary) {
String libraryDir = topLibrary.substring(0, end);
// Matches #import( or #source( followed by " or ' followed by anything
- // except dart: or /, at the beginning of a line.
- RegExp relativeImportRegExp =
- const RegExp('^#(import|source)[(]["\'](?!(dart:|/))([^"\']*)["\']');
+ // except dart:, dart-ext: or /, at the beginning of a line.
+ RegExp relativeImportRegExp = const RegExp(
+ '^#(import|source)[(]["\'](?!(dart:|dart-ext:|/))([^"\']*)["\']');
while (!toSearch.isEmpty()) {
var thisPass = toSearch;
toSearch = new HashSet<String>();
« tests/standalone/io/test_extension_test.dart ('K') | « tests/standalone/standalone.status ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698